/*
Skin Name: Nivo Slider Bar Theme
Skin URI: http://nivo.dev7studios.com
Description: The bottom bar skin for the Nivo Slider.
Version: 1.0
Author: Gilbert Pellegrom
Author URI: http://dev7studios.com
Supports Thumbs: false
*/

.theme-bar.slider-wrapper {
    position: relative;
    border: 1px solid #333;
    overflow: hidden;
}
.theme-bar .nivoSlider {
	position:relative;
	background:#fff url(loading.gif) no-repeat 50% 50%;
}
.theme-bar .nivoSlider img {
	position:absolute;
	top:0px;
	left:0px;
	display:none;
	background-color:white;
}
.theme-bar .nivoSlider a {
	border:0;
	display:block;
}

.theme-bar .nivo-controlNav {
    position: absolute;
    left: 0;
    bottom: -41px;
    z-index: 10;
    width: 100%;
    height: 30px;
	text-align: center;
	padding: 5px 0;
	border-top: 1px solid #333;
	background: #333;
    background: -moz-linear-gradient(top,  #565656 0%, #333333 100%); /* FF3.6+ */
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#565656), color-stop(100%,#333333)); /* Chrome,Safari4+ */
    background: -webkit-linear-gradient(top,  #565656 0%,#333333 100%); /* Chrome10+,Safari5.1+ */
    background: -o-linear-gradient(top,  #565656 0%,#333333 100%); /* Opera 11.10+ */
    background: -ms-linear-gradient(top,  #565656 0%,#333333 100%); /* IE10+ */
    background: linear-gradient(to bottom,  #565656 0%,#333333 100%); /* W3C */
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#565656', endColorstr='#333333',GradientType=0 ); /* IE6-9 */
    opacity: 0.5;
    -webkit-transition: all 200ms ease-in-out;
    -moz-transition: all 200ms ease-in-out;
    -o-transition: all 200ms ease-in-out;
    transition: all 200ms ease-in-out;
}
.theme-bar:hover .nivo-controlNav {
    bottom: 0;
    opacity: 1;
}
.theme-bar .nivo-controlNav a {
	display:inline-block;
	width:22px;
	height:22px;
	background:url(bullets.png) no-repeat;
	text-indent:-9999px;
	border:0;
	margin: 5px 2px 0 2px;
}
.theme-bar .nivo-controlNav a.active {
	background-position:0 -22px;
}

.theme-bar .nivo-directionNav a {
	display:block;
	border:0;
	color: #fff;
	text-transform: uppercase;
	top: auto;
	bottom: 10px;
	z-index: 11;
	font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
	font-size: 13px;
	line-height: 20px;
	opacity: 0.5;
    -webkit-transition: all 200ms ease-in-out;
    -moz-transition: all 200ms ease-in-out;
    -o-transition: all 200ms ease-in-out;
    transition: all 200ms ease-in-out;
}
.theme-bar a.nivo-nextNav { right: -50px; }
.theme-bar a.nivo-prevNav { left: -50px; }
.theme-bar:hover a.nivo-nextNav { 
    right: 15px; 
    opacity: 1;
}
.theme-bar:hover a.nivo-prevNav { 
    left: 15px; 
    opacity: 1;
}
.theme-bar .nivo-directionNav a:hover { color: #ddd; }

.theme-bar .nivo-caption {
    font-family: Helvetica, Arial, sans-serif;
    -webkit-transition: all 200ms ease-in-out;
    -moz-transition: all 200ms ease-in-out;
    -o-transition: all 200ms ease-in-out;
    transition: all 200ms ease-in-out;
}
.theme-bar:hover .nivo-caption {
    bottom: 41px;
}
.theme-bar .nivo-caption a {
    color:#fff;
    border-bottom:1px dotted #fff;
}
.theme-bar .nivo-caption a:hover {
    color:#fff;
}

.theme-bar .nivo-controlNav.nivo-thumbs-enabled {
	width: 100%;
}
.theme-bar .nivo-controlNav.nivo-thumbs-enabled a {
	width: auto;
	height: auto;
	background: none;
	margin-bottom: 5px;
}
.theme-bar .nivo-controlNav.nivo-thumbs-enabled img {
	display: block;
	width: 64px;
	height: auto;
}
